==> owncloud-8.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/lib/l10n/fa.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "نمیتوانید داخل دایرکتوری \"config\" تغییراتی ایجاد کنید",
    "See %s" : "مشاهده %s",
    "Sample configuration detected" : "فایل پیکربندی نمونه پیدا شد",
    "PHP %s or higher is required." : "PHP نسخه‌ی %s یا بالاتر نیاز است.",
    "Following databases are supported: %s" : "پایگاه‌داده‌ های ذکر شده مورد نیاز است: %s",
    "The command line tool %s could not be found" : "ابزار کامندلاین %s پیدا نشد",
    "Help" : "راه‌نما",
    "Personal" : "شخصی",
    "Users" : "کاربران",
    "Admin" : "مدیر",
    "Recommended" : "پیشنهاد شده",
    "No app name specified" : "اسم اپلیکیشن مشخص نشده‌ است",
    "Unknown filetype" : "نوع فایل ناشناخته",
    "Invalid image" : "عکس نامعتبر",
    "today" : "امروز",
    "yesterday" : "دیروز",
    "_%n day ago_::_%n days ago_" : ["%n روز پیش"],
    "last month" : "ماه قبل",
    "_%n month ago_::_%n months ago_" : ["%n ماه قبل"],
    "last year" : "سال قبل",
    "_%n year ago_::_%n years ago_" : ["%n سال پیش"],
    "_%n hour ago_::_%n hours ago_" : ["%n ساعت قبل"],
    "_%n minute ago_::_%n minutes ago_" : ["%n دقیقه قبل"],
    "seconds ago" : "ثانیه‌ها پیش",
    "web services under your control" : "سرویس های تحت وب در کنترل شما",
    "Empty filename is not allowed" : "نام فایل نمی‌تواند خالی باشد",
    "File name contains at least one invalid character" : "نام فایل دارای حداقل یک کاراکتر نامعتبر است",
    "File name is too long" : "نام فایل خیلی بزرگ است",
    "Application is not enabled" : "برنامه فعال نشده است",
    "Authentication error" : "خطا در اعتبار سنجی",
    "Token expired. Please reload page." : "رمز منقضی شده است. لطفا دوباره صفحه را بارگذاری نمایید.",
    "Unknown user" : "کاربر نامعلوم",
    "%s enter the database username." : "%s نام کاربری پایگاه داده را وارد نمایید.",
    "%s enter the database name." : "%s نام پایگاه داده را وارد نمایید.",
    "%s you may not use dots in the database name" : "%s شما نباید از نقطه در نام پایگاه داده استفاده نمایید.",
    "Oracle connection could not be established" : "ارتباط اراکل نمیتواند برقرار باشد.",
    "Oracle username and/or password not valid" : "نام کاربری و / یا رمزعبور اراکل معتبر نیست.",
    "DB Error: \"%s\"" : "خطای پایگاه داده: \"%s\"",
    "Offending command was: \"%s\"" : "دستور متخلف عبارت است از: \"%s\"",
    "You need to enter either an existing account or the administrator." : "شما نیاز به وارد کردن یک حساب کاربری موجود یا حساب مدیریتی دارید.",
    "Offending command was: \"%s\", name: %s, password: %s" : "دستور متخلف عبارت است از: \"%s\"، نام: \"%s\"، رمزعبور:\"%s\"",
    "PostgreSQL username and/or password not valid" : "PostgreSQL نام کاربری و / یا رمزعبور معتبر نیست.",
    "Set an admin username." : "یک نام کاربری برای مدیر تنظیم نمایید.",
    "Set an admin password." : "یک رمزعبور برای مدیر تنظیم نمایید.",
    "%s shared »%s« with you" : "%s به اشتراک گذاشته شده است »%s« توسط شما",
    "Could not find category \"%s\"" : "دسته بندی %s یافت نشد",
    "Apps" : "  برنامه ها",
    "A valid username must be provided" : "نام کاربری صحیح باید وارد شود",
    "A valid password must be provided" : "رمز عبور صحیح باید وارد شود",
    "The username is already being used" : "نام‌کاربری قبلا استفاده شده است",
    "Microsoft Windows Platform is not supported" : "بستر Microsoft Windows پشتیبانی نمی‎‌شود",
    "Cannot write into \"config\" directory" : "امکان نوشتن درون شاخه‌ی \"config\" وجود ندارد",
    "Please ask your server administrator to install the module." : "لطفا از مدیر سیستم بخواهید تا ماژول را نصب کند.",
    "PHP module %s not installed." : "ماژول PHP %s نصب نشده است.",
    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 نیاز است",
    "Please upgrade your database version" : "لطفا نسخه‌ی پایگاه‌داده‌ی خود را بروز کنید",
    "Error occurred while checking PostgreSQL version" : "خطا در هنگام بررسی نسخه‌ی PostgreSQL"
},
"nplurals=1; plural=0;");

==> owncloud-9.0.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/lib/l10n/fa.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "نمیتوانید داخل دایرکتوری \"config\" تغییراتی ایجاد کنید",
    "See %s" : "مشاهده %s",
    "Sample configuration detected" : "فایل پیکربندی نمونه پیدا شد",
    "PHP %s or higher is required." : "PHP نسخه‌ی %s یا بالاتر نیاز است.",
    "Following databases are supported: %s" : "پایگاه‌داده‌ های ذکر شده مورد نیاز است: %s",
    "The command line tool %s could not be found" : "ابزار کامندلاین %s پیدا نشد",
    "The library %s is not available." : "کتابخانه‌ی %s  در دسترس نیست.",
    "Library %s with a version higher than %s is required - available version %s." : "کتابخانه %s با نسخه‎‌ی بالاتر از %s نیاز است - نسخه‎ی موجود %s.",
    "Library %s with a version lower than %s is required - available version %s." : "کتابخانه %s با نسخه‎‌ی پایین‌تر از %s نیاز است - نسخه‎ی موجود %s.",
    "ownCloud %s or higher is required." : "ownCloud با نسخه‎ی %s یا بالاتر نیاز است.",
    "ownCloud %s or lower is required." : "ownCloud با نسخه‎ی %s یا پایین‌تر نیاز است.",
    "Help" : "راه‌نما",
    "Personal" : "شخصی",
    "Users" : "کاربران",
    "Admin" : "مدیر",
    "Recommended" : "پیشنهاد شده",
    "App \"%s\" cannot be installed because it is not compatible with this version of ownCloud." : "امکان نصب برنامه‌ی  \"%s\" به علت عدم سازگاری با این نسخه از ownCloud وجود ندارد.",
    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "امکان نصب برنامه \"%s\" با توجه به برآورده نکردن نیازمندی زیر وجود ندارد: %s",
    "No app name specified" : "اسم اپلیکیشن مشخص نشده‌ است",
    "Unknown filetype" : "نوع فایل ناشناخته",
    "Invalid image" : "عکس نامعتبر",
    "today" : "امروز",
    "yesterday" : "دیروز",
    "_%n day ago_::_%n days ago_" : ["%n روز پیش"],
    "last month" : "ماه قبل",
    "_%n month ago_::_%n months ago_" : ["%n ماه قبل"],
    "last year" : "سال قبل",
    "_%n year ago_::_%n years ago_" : ["%n سال پیش"],
    "_%n hour ago_::_%n hours ago_" : ["%n ساعت قبل"],
    "_%n minute ago_::_%n minutes ago_" : ["%n دقیقه قبل"],
    "seconds ago" : "ثانیه‌ها پیش",
    "web services under your control" : "سرویس های تحت وب در کنترل شما",
    "Empty filename is not allowed" : "نام فایل نمی‌تواند خالی باشد",
    "File name is a reserved word" : "این نام فایل جزو کلمات رزرو می‌باشد",
    "File name contains at least one invalid character" : "نام فایل دارای حداقل یک کاراکتر نامعتبر است",
    "File name is too long" : "نام فایل خیلی بزرگ است",
    "File is currently busy, please try again later" : "فایل در حال حاضر مشغول است، لطفا مجددا تلاش کنید",
    "Can't read file" : "امکان خواندن فایل وجود ندارد",
    "App directory already exists" : "برنامه در حال حاضر وجود دارد",
    "Can't create app folder. Please fix permissions. %s" : "امکان ایجاد پوشه‌ی برنامه وجود ندارد. لطفا اجازه‌های دسترسی را تصحیح کنید. %s",
    "No source specified when installing app" : "هیچ مبدائی در زمان نصب برنامه مشخص نشده است",
    "Application is not enabled" : "برنامه فعال نشده است",
    "Authentication error" : "خطا در اعتبار سنجی",
    "Token expired. Please reload page." : "رمز منقضی شده است. لطفا دوباره صفحه را بارگذاری نمایید.",
    "Unknown user" : "کاربر نامعلوم",
    "%s enter the database username." : "%s نام کاربری پایگاه داده را وارد نمایید.",
    "%s enter the database name." : "%s نام پایگاه داده را وارد نمایید.",
    "%s you may not use dots in the database name" : "%s شما نباید از نقطه در نام پایگاه داده استفاده نمایید.",
    "Oracle connection could not be established" : "ارتباط اراکل نمیتواند برقرار باشد.",
    "Oracle username and/or password not valid" : "نام کاربری و / یا رمزعبور اراکل معتبر نیست.",
    "DB Error: \"%s\"" : "خطای پایگاه داده: \"%s\"",
    "Offending command was: \"%s\"" : "دستور متخلف عبارت است از: \"%s\"",
    "You need to enter either an existing account or the administrator." : "شما نیاز به وارد کردن یک حساب کاربری موجود یا حساب مدیریتی دارید.",
    "Offending command was: \"%s\", name: %s, password: %s" : "دستور متخلف عبارت است از: \"%s\"، نام: \"%s\"، رمزعبور:\"%s\"",
    "PostgreSQL username and/or password not valid" : "PostgreSQL نام کاربری و / یا رمزعبور معتبر نیست.",
    "Set an admin username." : "یک نام کاربری برای مدیر تنظیم نمایید.",
    "Set an admin password." : "یک رمزعبور برای مدیر تنظیم نمایید.",
    "%s shared »%s« with you" : "%s به اشتراک گذاشته شده است »%s« توسط شما",
    "Could not find category \"%s\"" : "دسته بندی %s یافت نشد",
    "Apps" : "  برنامه ها",
    "A valid username must be provided" : "نام کاربری صحیح باید وارد شود",
    "A valid password must be provided" : "رمز عبور صحیح باید وارد شود",
    "The username is already being used" : "نام‌کاربری قبلا استفاده شده است",
    "Microsoft Windows Platform is not supported" : "بستر Microsoft Windows پشتیبانی نمی‎‌شود",
    "Cannot write into \"config\" directory" : "امکان نوشتن درون شاخه‌ی \"config\" وجود ندارد",
    "Please ask your server administrator to install the module." : "لطفا از مدیر سیستم بخواهید تا ماژول را نصب کند.",
    "PHP module %s not installed." : "ماژول PHP %s نصب نشده است.",
    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 نیاز است",
    "Please upgrade your database version" : "لطفا نسخه‌ی پایگاه‌داده‌ی خود را بروز کنید",
    "Storage not available" : "فضای ذخیره سازی موجود نیست"
},
"nplurals=1; plural=0;");
